#!/bin/bash

# Check are you root?
echo "****************************************"
echo "   ShenZhen KTUSB TouchScreen Install"
echo "****************************************"
echo ""

whoami | egrep "^root$" >/dev/null

if [ $? -ne 0 ]; then
  echo "Warning: You are not root!"
  echo "         Installation Failed!"
  exit
fi

echo "Show some information and check them!"

# Check what kind of the X Server is!
if [ -f /var/log/Xorg.0.log ]; then
  PATH_XServerConfig=$(egrep "Using config file" /var/log/Xorg.0.log|cut -d" " -f5|cut -d\" -f2)
  echo "X Window Config is in $PATH_XServerConfig"
  PATH_XServerModule=$(egrep "ModulePath set to" /var/log/Xorg.0.log|cut -d" " -f5|cut -d\" -f2)
  echo "X Window Module Path is in $PATH_XServerModule"
else
  echo "Warning: Don't know where is your X Server config file."
  echo "         Installation Failed!"
  exit
fi

# I want to know where is your path!
echo $0 | egrep ^/ >/dev/null
if [ $? == 0 ]; then
  INSTALL_PATH=${0%/*}
else
  INSTALL_PATH=${PWD}/${0%/*}
fi

# the file is main file that I want to change!
TARGET_FILE=$PATH_XServerConfig

# Start to install
mkdir /etc/ktusb

cp -f "$INSTALL_PATH"/evtouch_drv.so "$PATH_XServerModule"/input

cp $TARGET_FILE ${TARGET_FILE}.bak.touch

sed -e '$a\
\
Section "InputDevice"\
    Identifier  "kt"\
    Driver 		"evtouch"\
    Option 		"Device" "/dev/input/ktusb"\
    Option 		"DeviceName"	 "KTUSB"\
    Option 		"ReportingMode"	 "Raw"\
    Option		"Emulate3Buttons"\
    Option		"Emulate3Timeout" "50"\
    Option 		"SendCoreEvents" 	"On"\
EndSection \
' \
-e '/ServerLayout/,/EndSection/s/EndSection/        InputDevice     "kt"  "SendCoreEvents"\
EndSection/' ${TARGET_FILE}.bak.touch>$TARGET_FILE 

cp -f "$INSTALL_PATH"/KTcalibrate /etc/ktusb
cp -f "$INSTALL_PATH"/uninstall.sh /etc/ktusb
cp -f "$INSTALL_PATH"/readme.txt /etc/ktusb
cp -f "$INSTALL_PATH"/KT3Point.cal /etc
chmod 777 /etc/ktusb/*
cp -f "$INSTALL_PATH"/69-touchscreen.rules /etc/udev/rules.d
chmod 777 /etc/udev/rules.d/69-touchscreen.rules

echo
echo "Touch Driver has Installed."
echo
echo "Calibration tools are in the directory /etc/ktusb"
echo "you can copy them to your desktop."

choice=" "
while [ "$choice" != "y" ]; do
echo
echo -n "Do you want to Reboot now? (y/n):"
read choice
echo
case $choice in
      y|Y) echo 'Rebooting...'
           reboot
           echo;;
      n|N) echo 'It is recommaned to reboot after driver installed'
           echo
           break;;
      *) ;;
esac
done
